----------------------------------------------------------------------------- 
-- Units of Measurement  -  The International System of Units (SI)*
------------------------------------------------------------------------------
-- Written by Hartmut Langmach <langmach@wias-berlin.de>
-- Adapted by Juergen Fuhrmann <fuhrmann@wias-berlin.de

const_pi =3.1415926535897932;



--[[ Port to lua5! 
------------------------------------------------------------------------------
-- Protect these valuable data in the proper way
si_constant_tag=newtag()                   -- tag for read-only values
si_constant_table_tag=newtag()                   -- tag for read-only tables

function si_constant_table_settable(t,x,v)       -- protects assignment
  error("error setting '"..x.."': Physical Units table is write protected")
end

function si_constant_table_gettable(t,x)         -- get the actual value
 return rawget(t,x)
end

function si_constant_setglobal(x)                 -- protects assignment
  error(x.." is a pysical constant or unit")
end

function si_constant_getglobal(x,value)           -- get the actual value
  return value.value
end

settagmethod(si_constant_tag,"getglobal",si_constant_getglobal)
settagmethod(si_constant_tag,"setglobal",si_constant_setglobal)
settagmethod(si_constant_table_tag,"gettable",si_constant_table_gettable)
settagmethod(si_constant_table_tag,"settable",si_constant_table_settable)

function SIProtect(table)
  settag(table,si_constant_table_tag)
end
]]


SI     ={}  -- the names of SI units are collected in this table  
SIUnits={}  -- the SI unit symbols are collected in this table  


------------------------------------------------------------------------------
-- The 7 basic units of SI  -- english names
------------------------------------------------------------------------------

SI.meter     =1;                               -- distance
SI.kilogram  =1;                               -- mass
SI.second    =1;                               -- time
SI.ampere    =1;                               -- electric current
SI.kelvin    =1;                               -- temperature
SI.candela   =1;                               -- luminous intensity
SI.mole      =1;                               -- amount of substance
     
-------------------------------------------------------------------------------
-- 22 derived SI units -- english names
-------------------------------------------------------------------------------
SI.radian    =SI.meter/SI.meter;       -- plane angle 
SI.steradian =SI.meter^2/SI.meter^2;   -- solid angle

SI.hertz     =1/SI.second;                 -- frequency
SI.newton    =SI.meter*SI.kilogram/SI.second^2; -- force
SI.pascal    =SI.newton/SI.meter^2;    -- pressure, stress
SI.joule     =SI.newton*SI.meter;      -- energy, work
SI.watt      =SI.joule/SI.second;      -- power, radiant flux

SI.coulomb   =SI.ampere*SI.second;     -- electric charge
SI.volt      =SI.watt/SI.ampere;       -- electric potential
SI.farad     =SI.coulomb/SI.volt;      -- electric capacitance
SI.ohm       =SI.volt/SI.ampere;       -- electric resistance
SI.siemens   =SI.ampere/SI.volt;       -- electric conductance

SI.weber     =SI.second*SI.volt;       -- magnetic flux
SI.tesla     =SI.weber/SI.meter^2;     -- magnetic flux density
SI.henry     =SI.weber/SI.ampere;      -- inductance

SI.lumen     =SI.candela*SI.steradian; -- luminous flux
SI.lux       =SI.lumen/SI.meter^2;     -- illuminance
SI.becquerel =1/SI.second;                 -- activity
SI.gray      =SI.joule/SI.kilogram;    -- absorbed dose
SI.sievert   =SI.joule/SI.kilogram;    -- dose equivalent

SI.katal     =SI.mole/SI.second;       -- catalytic activity

SI.celsius   =function(v) return (v+273.15)*SI.kelvin; end; -- degree Celsius

-- Remark:
-- the function SI.celsius is used as follows:   Temp = SI.celsius(20) 
-- this is equivalent to                         Temp = (20+273.15)*SI.kelvin
-- i.e. the result is a temperature measured in kelvin.
------------------------------------------------------------------------------- 

SI.gram      =1e-3*SI.kilogram;                   -- mass          



-------------------------------------------------------------------------------
-- SI units -- international symbols                                 
--             or alternative symbols proposed in ISO 2955 (DIN 66030)
--
-- Remark: All symbols should be chosen accordingly to ISO (or DIN).       
-- Remark: Some of the proposed symbols are very close to each other, 
--         e.g.  s for second  vs.  S for siemens, etc..
--         in that case it could be better to use the alternative notations 
--         proposed in DIN 66030.  
-------------------------------------------------------------------------------
SIUnits.m    =SI.meter;    
SIUnits.kg   =SI.kilogram;  
SIUnits.s    =SI.second;    
SIUnits.A    =SI.ampere;    
SIUnits.K    =SI.kelvin;    
SIUnits.cd   =SI.candela;   
SIUnits.mol  =SI.mole;      
--------------- 
SIUnits.rad =SI.radian;    
SIUnits.sr  =SI.steradian; 
--------------- 
SIUnits.Hz  =SI.hertz;
SIUnits.N   =SI.newton;
SIUnits.Pa  =SI.pascal; 
SIUnits.J   =SI.joule;  
SIUnits.W   =SI.watt;   
--------------- 
SIUnits.C   =SI.coulomb;
SIUnits.V   =SI.volt;   
SIUnits.F   =SI.farad;  
SIUnits.Ohm =SI.ohm;     -- Ohm  is used instead of greek letter Omega
SIUnits.S   =SI.siemens; -- Sie  could be used instead of the symbol  S 
--------------- 
SIUnits.Wb  =SI.weber;  
SIUnits.T   =SI.tesla;  
SIUnits.H   =SI.henry;  
--------------- 
SIUnits.lm  =SI.lumen;  
SIUnits.lx  =SI.lux;    
SIUnits.Bq  =SI.becquerel; 
SIUnits.Gy  =SI.gray;   
SIUnits.Sv  =SI.sievert;
--------------- 
SIUnits.kat =SI.katal;  
---------------
SIUnits.Cel =SI.celsius; -- Cel is used for degree ^o C 
---------------
SIUnits.g   =SI.gram; -- g is the official symbol for 0.001*kg 
        
------------------------------------------------------------------------------
-- References:
-- [1] Fischer, Vogelsang: SI, Groessen und Einheiten in Physik und Technik
--     Verlag Technik Berlin und Muenchen, 6. Auflage, 1993
-- [2] National Institute of Standards and Technology (NIST):
--     International System of Units (SI)
--     http://physics.nist.gov/cuu/Units/index.html 
-- [3] Russ Rowlett (University of North Carolina at Chapel Hill)
--     Units of Measurements
--     http://www.unc.edu/~rowlett/units/index.html
------------------------------------------------------------------------------
-- Notes:
-- * SI = Le Syste`me International d' Unites
-- 
------------------------------------------------------------------------------


------------------------------------------------------------------------------
--    Values of the Fundamental Physical Constants 
--    measured in SI *

--    based on: 
--    CODATA Recommended Values of the Fundamental Physical Constants. 1998


PhConst={} -- this table contains the defined physical constants
PhCoErr={} -- this table contains the standard uncertainties       

------------------------------------------------------------------------

do -- definition of constants

-- local const_pi =PI; 
-- local const_PI =constant(math_const.PI); 

-- definitions of symbols for units of measurements

local m   =SIUnits.m;            
local kg  =SIUnits.kg;         
local s   =SIUnits.s;            
local A   =SIUnits.A;            
local K   =SIUnits.K;            
local cd  =SIUnits.cd;          
local mol =SIUnits.mol;            
--------------- 
local rad =SIUnits.rad;         
local sr  =SIUnits.sr;       
--------------- 
local Hz  =SIUnits.Hz; 
local MHz =1e6*Hz;
local N   =SIUnits.N;       
local Pa  =SIUnits.Pa;       
local J   =SIUnits.J;         
local W   =SIUnits.W;          
--------------- 
local C   =SIUnits.C;       
local V   =SIUnits.V;          
local F   =SIUnits.F;         
local Ohm =SIUnits.Ohm;  
local S   =SIUnits.S; 
--------------- 
local Wb  =SIUnits.Wb;        
local T   =SIUnits.T;         
local H   =SIUnits.H;         
--------------- 
local lm  =SIUnits.lm;        
local lx  =SIUnits.lx;          
local Bq  =SIUnits.Bq;       
local Gy  =SIUnits.Gy;         
local Sv  =SIUnits.Sv;      
--------------- 
local kat =SIUnits.kat;       
---------------
        

------------------------------------------------------------------------
-- physical constants used in definitions of units
------------------------------------------------------------------------
						      
PhConst.elementary_charge                   =1.602176462e-19*C;
PhCoErr.elementary_charge_err               =0.000000063e-19*C;

PhConst.atomic_mass_constant                =1.66053873e-27*kg;         
PhCoErr.atomic_mass_constant_err            =0.00000013e-27*kg;        

------------------------------------------------------------------------

local eV  =PhConst.elementary_charge*SI.volt;  -- electron_volt
local MeV =1e6*eV;
local GeV =1e9*eV;

local u   =PhConst.atomic_mass_constant;  

-------------------------------------------------------------------------------
-- UNIVERSAL
-------------------------------------------------------------------------------

-- c = speed of light
PhConst.speed_of_light_in_vacuum                 =299792458*m/s;
PhCoErr.speed_of_light_in_vacuum_err             =0*m/s;       
-- (exact)

PhConst.magnetic_constant                        =4*const_pi*1e-7*N/A^2;
PhCoErr.magnetic_constant_err                    =0*N/A^2;
-- (exact)

PhConst.electric_constant =1/PhConst.magnetic_constant/PhConst.speed_of_light_in_vacuum^2;
-- PhConst.electric_constant                     =8.854187817e-12*F/m;
PhCoErr.electric_constant_err                    =0*F/m;
-- (exact)

PhConst.characteristic_impedance_of_vacuum       =PhConst.magnetic_constant*PhConst.speed_of_light_in_vacuum;
-- PhConst.characteristic_impedance_of_vacuum       =376.730313461*Ohm;
PhCoErr.characteristic_impedance_of_vacuum_err   =0*Ohm;
-- (exact)

PhConst.Newtonian_constant_of_gravitation        =6.673e-11*m^3/kg/s^2;
PhCoErr.Newtonian_constant_of_gravitation_err    =0.010e-11*m^3/kg/s^2;   

-- h = Planck_constant
PhConst.Planck_constant                          =6.62606876e-34*J*s;
PhCoErr.Planck_constant_err                      =0.00000052e-34*J*s;

-- in eV s (cf. also Remark 4) 
-- PhConst.Planck_constant                          =4.13566727e-15*eV*s;
-- PhCoErr.Planck_constant_err                      =constant(0.00000016e-15*eV*s);


PhConst.Planck_constant_over_2pi                 =1.054571596e-34*J*s;
PhCoErr.Planck_constant_over_2pi_err             =0.000000082e-34*J*s;

-- in eV s  (cf. also Remark 4)
-- PhConst.Planck_constant_over_2pi                 =6.58211889e-16*eV*s;
-- PhCoErr.Planck_constant_over_2pi_err             =0.00000026e-16*eV*s;

PhConst.Planck_mass                              =2.1767e-8*kg;
PhCoErr.Planck_mass_err                          =0.0016e-8*kg;

PhConst.Planck_length                            =1.6160e-35*m;
PhCoErr.Planck_length_err                        =0.0012e-35*m;

PhConst.Planck_time                              =5.3906e-44*s;  
PhCoErr.Planck_time_err                          =0.0040e-44*s; 


-------------------------------------------------------------------------------
-- ELECTROMAGNETIC
-------------------------------------------------------------------------------

-- already defined above
-- PhConst.elementary_charge                     =1.602176462e-19*C;
-- PhCoErr.elementary_charge_err                 =0.000000063e-19*C;

PhConst.elementary_charge_over_h              =2.417989491e14*A/J;
PhCoErr.elementary_charge_over_h_err          =0.000000095e14*A/J;

PhConst.magnetic_flux_quantum                 =2.067833636e-15*Wb;
PhCoErr.magnetic_flux_quantum_err             =0.000000081e-15*Wb;

PhConst.conductance_quantum                   =7.748091696e-5*S;
PhCoErr.conductance_quantum_err               =0.000000028e-5*S;

PhConst.inverse_of_conductance_quantum        =12906.403786*Ohm;
PhCoErr.inverse_of_conductance_quantum_err    =    0.000047*Ohm;

PhConst.Josephson_constant                    =483597.898e9*Hz/V;   
PhCoErr.Josephson_constant_err                =     0.019e9*Hz/V;
-- cf. Remark 1.a

PhConst.von_Klitzing_constant                 =25812.807572*Ohm;    
PhCoErr.von_Klitzing_constant_err             =    0.000095*Ohm;
-- cf. Remark 1.b

PhConst.Bohr_magneton                         =927.400899e-26*J/T;
PhCoErr.Bohr_magneton_err                     =  0.000037e-26*J/T;

-- in eVcf. also Remark4
-- PhConst.Bohr_magneton                         =5.788381749e-5*eV/T;
-- PhCoErr.Bohr_magneton_err                     =0.000000043e-5*eV/T;

PhConst.Bohr_magneton_over_h                  =13.99624624e9*Hz/T;
PhCoErr.Bohr_magneton_over_h_err              = 0.00000056e9*Hz/T;

PhConst.Bohr_magneton_over_hc                 =46.6864521/m/T;
PhCoErr.Bohr_magneton_over_hc_err             = 0.0000019/m/T;

PhConst.Bohr_magneton_over_k                  =0.6717131*K/T;
PhCoErr.Bohr_magneton_over_k_err              =0.0000012*K/T;

PhConst.nuclear_magneton                      =5.05078317e-27*J/T;
PhCoErr.nuclear_magneton_err                  =0.00000020e-27*J/T;

-- in eVcf. also Remark4
-- PhConst.nuclear_magneton                      =3.152451238e-8*eV/T;
-- PhConst.nuclear_magneton_err                  =0.000000024e-8*eV/T;

PhConst.nuclear_magneton_over_h               =7.62259396*MHz/T;
PhCoErr.nuclear_magneton_over_h_err           =0.00000031*MHz/T;

PhConst.nuclear_magneton_over_hc              =2.54262366e-2/m/T;
PhCoErr.nuclear_magneton_over_hc_err          =0.00000010e-2/m/T;

PhConst.nuclear_magneton_over_k               =3.6582638e-4*K/T;
PhCoErr.nuclear_magneton_over_k_err           =0.0000064e-4*K/T;

-------------------------------------------------------------------------------
-- ATOMIC AND NUCLEAR
-------------------------------------------------------------------------------

-- General ---------------------------------------------------------------


PhConst.fine_structure_constant               =7.297352533e-3;
PhCoErr.fine_structure_constant_err           =0.000000027e-3;

PhConst.inverse_fine_structure_constant       =137.03599976;
PhCoErr.inverse_fine_structure_constant_err   =  0.00000050;

PhConst.Rydberg_constant                      =10973731.568549/m;
PhCoErr.Rydberg_constant_err                  =       0.000083/m;

PhConst.Rydberg_constant_times_c              =3.289841960368e15*Hz;
PhCoErr.Rydberg_constant_times_c_err          =0.000000000025e15*Hz;

PhConst.Rydberg_constant_times_hc             =2.17987190e-18*J;
PhCoErr.Rydberg_constant_times_hc_err         =0.00000017e-18*J;

--cf. also Remark4
-- PhConst.Rydberg_constant_times_hc             =13.60569172*eV;
-- PhCoErr.Rydberg_constant_times_hc_err         = 0.00000053*eV;

PhConst.Bohr_radius                           =0.5291772083e-10*m;
PhCoErr.Bohr_radius_err                       =0.0000000019e-10*m;

PhConst.Hartree_energy                        =4.35974381e-18*J;
PhCoErr.Hartree_energy_err                    =0.00000034e-18*J;

-- in eV  (cf. also Remark4)
-- PhConst.Hartree_energy                        =27.2113834*eV;
-- PhCoErr.Hartree_energy_err                    = 0.0000011*eV;

PhConst.quantum_of_circulation                =3.636947516e-4*m^2/s;
PhCoErr.quantum_of_circulation_err            =0.000000027e-4*m^2/s;

PhConst.quantum_of_circulation_2              =7.273895032e-4*m^2/s;
PhCoErr.quantum_of_circulation_2_err          =0.000000053e-4*m^2/s;


-- Electroweak ----------------------------------------------------------

PhConst.Fermi_coupling_constant               =1.16639e-5/GeV^2;   
PhCoErr.Fermi_coupling_constant_err           =0.00001e-5/GeV^2;
-- cf. Remark 1.c

PhConst.weak_mixing_angle                     =0.2224;             
PhCoErr.weak_mixing_angle_err                 =0.0019;
-- cf. Remark 1.d


-- Electron, e ----------------------------------------------------------

PhConst.electron_mass                         =9.10938188e-31*kg;
PhCoErr.electron_mass_err                     =0.00000072e-31*kg;

PhConst.electron_relative_atomic_mass         =5.485799110e-4;
PhCoErr.electron_relative_atomic_mass_err     =0.000000012e-4;

-- electron relative atomic mass times u 
-- PhConst.electron_mass                         =5.485799110e-4*u;
-- PhCoErr.electron_mass_err                     =0.000000012e-4*u;

PhConst.electron_mass_energy_equivalent       =8.18710414e-14*J;
PhCoErr.electron_mass_energy_equivalent_err   =0.00000064e-14*J;

-- in MeV  (cf. also Remark4)
-- PhConst.electron_mass_energy_equivalent       =constant(0.510998902*MeV);
-- PhCoErr.electron_mass_energy_equivalent_err   =constant(0.000000021*MeV);

PhConst.electron_muon_mass_ratio              =4.83633210e-3;
PhCoErr.electron_muon_mass_ratio_err          =0.00000015e-3;

PhConst.electron_tau_mass_ratio               =2.87555e-4;
PhCoErr.electron_tau_mass_ratio_err           =0.00047e-4;

PhConst.electron_proton_mass_ratio            =5.446170232e-4;
PhCoErr.electron_proton_mass_ratio_err        =0.000000012e-4;

PhConst.electron_neutron_mass_ratio           =5.438673462e-4;
PhCoErr.electron_neutron_mass_ratio_err       =0.000000012e-4;

PhConst.electron_deuteron_mass_ratio          =2.7244371170e-4;
PhCoErr.electron_deuteron_mass_ratio_err      =0.0000000058e-4;

PhConst.electron_to_alpha_particle_mass_ratio      =1.3709335611e-4;
PhCoErr.electron_to_alpha_particle_mass_ratio_err  =0.0000000029e-4;

PhConst.electron_charge_to_mass_quotient      =-1.758820174e11*C/kg;
PhCoErr.electron_charge_to_mass_quotient_err  =-0.000000071e11*C/kg;

PhConst.electron_molar_mass                   =5.485799110e-7*kg/mol;
PhCoErr.electron_molar_mass_err               =0.000000012e-7*kg/mol;

PhConst.Compton_wavelength                    =2.426310215e-12*m;
PhCoErr.Compton_wavelength_err                =0.000000018e-12*m;

PhConst.Compton_wavelength_over_2pi           =386.1592642e-15*m;
PhCoErr.Compton_wavelength_over_2pi_err       =  0.0000028e-15*m;

PhConst.classical_electron_radius             =2.817940285e-15*m;
PhCoErr.classical_electron_radius_err         =0.000000031e-15*m;

PhConst.Thomson_cross_section                 =0.665245854e-28*m;
PhCoErr.Thomson_cross_section_err             =0.000000015e-28*m;

PhConst.electron_magnetic_moment              =-928.476362e-26*J/T;
PhCoErr.electron_magnetic_moment_err          =  -0.000037e-26*J/T;

PhConst.electron_magnetic_moment_to_Bohr_magneton_ratio      =-1.0011596521869;
PhCoErr.electron_magnetic_moment_to_Bohr_magneton_ratio_err  =-0.0000000000041;

PhConst.electron_magnetic_moment_to_nuclear_magneton_ratio        =-1838.2819660;
PhCoErr.electron_magnetic_moment_to_nuclear_magneton_ratio_err    =   -0.0000039;

PhConst.electron_magnetic_moment_anomaly      =1.1596521869e-3;
PhCoErr.electron_magnetic_moment_anomaly_err  =0.0000000041e-3;

PhConst.electron_g_factor                     =-2.0023193043737;
PhCoErr.electron_g_factor_err                 =-0.0000000000082;

PhConst.electron_muon_magnetic_moment_ratio        =206.7669720;
PhCoErr.electron_muon_magnetic_moment_ratio_err    =  0.0000063;

PhConst.electron_proton_magnetic_moment_ratio      =-658.2106875;
PhCoErr.electron_proton_magnetic_moment_ratio_err  =  -0.0000066;

PhConst.electron_to_shielded_proton_magnetic_moment_ratio     =-658.2275954;                     
PhCoErr.electron_to_shielded_proton_magnetic_moment_ratio_err =  -0.0000071;
-- (H2O, sphere, 25*Cel)

PhConst.electron_neutron_magnetic_moment_ratio     =960.92050;
PhCoErr.electron_neutron_magnetic_moment_ratio_err =  0.00023;

PhConst.electron_deuteron_magnetic_moment_ratio    =-2143.923498;
PhCoErr.electron_deuteron_magnetic_moment_ratio_err =   -0.000023;

PhConst.electron_to_shielded_helion_magnetic_moment_ratio     =864.058255;   
PhCoErr.electron_to_shielded_helion_magnetic_moment_ratio_err =  0.000010;
-- (gas, sphere, 25*Cel)
-- cf. Remark 1.e

PhConst.electron_gyromagnetic_ratio                =1.760859794e11/s/T;
PhCoErr.electron_gyromagnetic_ratio_err            =0.000000071e11/s/T;

PhConst.electron_gyromagnetic_ratio_over_2pi       =28024.9540*MHz/T;
PhCoErr.electron_gyromagnetic_ratio_over_2pi_err   =    0.0011*MHz/T;

---- Muon ---------------------------------------------------------------

PhConst.muon_mass                             =1.88353109e-28*kg;
PhCoErr.muon_mass_err                         =0.00000016e-28*kg;

PhConst.muon_relative_atomic_mass             =0.1134289168;  
PhCoErr.muon_relative_atomic_mass_err         =0.0000000034;  

-- muon relative atomic mass times u:
-- PhConst.muon_mass                             =0.1134289168*u;
-- PhCoErr.muon_mass_err                         =0.0000000034*u;

PhConst.muon_mass_energy_equivalent           =1.69283332e-11*J;
PhCoErr.muon_mass_energy_equivalent_err       =0.00000014e-11*J;

-- in MeV (cf. also Remark4)
-- PhConst.muon_mass_energy_equivalent           =constant(105.6583568*MeV);
-- PhCoErr.muon_mass_energy_equivalent_err       =constant(  0.0000052*MeV);

PhConst.muon_electron_mass_ratio              =206.7682657;
PhCoErr.muon_electron_mass_ratio_err          =  0.0000063;

PhConst.muon_tau_mass_ratio                   =5.94572e-2;
PhCoErr.muon_tau_mass_ratio_err               =0.00097e-2;

PhConst.muon_proton_mass_ratio                =0.1126095173;
PhCoErr.muon_proton_mass_ratio_err            =0.0000000034;

PhConst.muon_neutron_mass_ratio               =0.1124545079;
PhCoErr.muon_neutron_mass_ratio_err           =0.0000000034;

PhConst.muon_molar_mass                       =0.1134289168e-3*kg/mol;
PhCoErr.muon_molar_mass_err                   =0.0000000034e-3*kg/mol;

PhConst.muon_Compton_wavelength               =11.73444197e-15*m;
PhCoErr.muon_Compton_wavelength_err           = 0.00000035e-15*m;

PhConst.muon_Compton_wavelength_over_2pi      =1.867594444e-15*m;
PhCoErr.muon_Compton_wavelength_over_2pi_err  =0.000000055e-15*m;

PhConst.muon_magnetic_moment                  =-4.49044813e-26*J/T;
PhCoErr.muon_magnetic_moment_err              =-0.00000022e-26*J/T;

PhConst.muon_magnetic_moment_to_Bohr_magneton_ratio     =-4.84197085e-3;
PhCoErr.muon_magnetic_moment_to_Bohr_magneton_ratio_err =-0.00000015e-3;

PhConst.muon_magnetic_moment_to_nuclear_magneton_ratio      =-8.89059770;
PhCoErr.muon_magnetic_moment_to_nuclear_magneton_ratio_err  =-0.00000027;

PhConst.muon_magnetic_moment_anomaly          =1.16591602e-3;
PhCoErr.muon_magnetic_moment_anomaly_err      =0.00000064e-3;

PhConst.muon_g_factor                         =-2.0023318320;
PhCoErr.muon_g_factor_err                     =-0.0000000013;

PhConst.muon_proton_magnetic_moment_ratio     =-3.18334539;
PhCoErr.muon_proton_magnetic_moment_ratio_err =-0.00000010;


---- Tau ---------------------------------------------------------------

PhConst.tau_mass                              =3.16788e-27*kg;       
PhCoErr.tau_mass_err                          =0.00052e-27*kg;
-- cf. Remark 1.f

PhConst.tau_relative_atomic_mass              =1.90774;  
PhCoErr.tau_relative_atomic_mass_err          =0.00031;  

-- tau relative_atomic_mass_times_u:
-- PhConst.tau_mass                              =1.90774*u;
-- PhCoErr.tau_mass_err                          =0.00031*u;

PhConst.tau_mass_energy_equivalent            =2.84715e-10*J;
PhCoErr.tau_mass_energy_equivalent_err        =0.00046e-10*J;

--cf. also Remark4 
-- PhConst.tau_mass_energy_equivalent            =1777.05*MeV;
-- PhCoErr.tau_mass_energy_equivalent_err        =   0.29*MeV;

PhConst.tau_electron_mass_ratio               =3477.60;
PhCoErr.tau_electron_mass_ratio_err           =   0.57;

PhConst.tau_muon_mass_ratio                   =16.8188;
PhCoErr.tau_muon_mass_ratio_err               = 0.0027;

PhConst.tau_proton_mass_ratio                 =1.89396;
PhCoErr.tau_proton_mass_ratio_err             =0.00031;

PhConst.tau_neutron_mass_ratio                =1.89135;
PhCoErr.tau_neutron_mass_ratio_err            =0.00031;

PhConst.tau_molar_mass                        =1.90774e-3*kg/mol;
PhCoErr.tau_molar_mass_err                    =0.00031e-3*kg/mol;

PhConst.tau_Compton_wavelength                =0.69770e-15*m;
PhCoErr.tau_Compton_wavelength_err            =0.00011e-15*m;

PhConst.tau_Compton_wavelength_over_2pi       =0.111042e-15*m;
PhCoErr.tau_Compton_wavelength_over_2pi_err   =0.000018e-15*m;

-- Proton, p ------------------------------------------------------------

PhConst.proton_mass                           =1.67262158e-27*kg;
PhCoErr.proton_mass_err                       =0.00000013e-27*kg;

PhConst.proton_relative_atomic_mass           =1.00727646688;    
PhCoErr.proton_relative_atomic_mass_err       =0.00000000013;  

-- proton relative atomic mass times u:
-- PhConst.proton_mass                           =1.00727646688*u;
-- PhCoErr.proton_mass_err                       =0.00000000013*u;

PhConst.proton_mass_energy_equivalent         =1.50327731e-10*J;
PhCoErr.proton_mass_energy_equivalent_err     =0.00000012e-10*J;

-- in MeV  (cf. also Remark4)
-- PhConst.proton_mass_energy_equivalent         =938.271998*MeV;
-- PhCoErr.proton_mass_energy_equivalent_err     =  0.000038*MeV;

PhConst.proton_electron_mass_ratio            =1836.1526675;
PhCoErr.proton_electron_mass_ratio_err        =   0.0000039;

PhConst.proton_muon_mass_ratio                =8.88024408;
PhCoErr.proton_muon_mass_ratio_err            =0.00000027;

PhConst.proton_tau_mass_ratio                 =0.527994;
PhCoErr.proton_tau_mass_ratio_err             =0.000086;

PhConst.proton_neutron_mass_ratio             =0.99862347855;
PhCoErr.proton_neutron_mass_ratio_err         =0.00000000058;

PhConst.proton_charge_to_mass_quotient        =9.57883408e7*C/kg;
PhCoErr.proton_charge_to_mass_quotient_err    =0.00000038e7*C/kg;

PhConst.proton_molar_mass                     =1.00727646688e-3*kg/mol;
PhCoErr.proton_molar_mass_err                 =0.00000000013e-3*kg/mol;

PhConst.proton_Compton_wavelength             =1.321409847e-15*m;
PhCoErr.proton_Compton_wavelength_err         =0.000000010e-15*m;

PhConst.proton_Compton_wavelength_over_2pi     =0.2103089089e-15*m;
PhCoErr.proton_Compton_wavelength_over_2pi_err =0.0000000016e-15*m;

PhConst.proton_magnetic_moment                =1.410606633e-26*J/T;
PhCoErr.proton_magnetic_moment_err            =0.000000058e-26*J/T;

PhConst.proton_magnetic_moment_to_Bohr_magneton_ratio        =1.521032203e-3;
PhCoErr.proton_magnetic_moment_to_Bohr_magneton_ratio_err    =0.000000015e-3;

PhConst.proton_magnetic_moment_to_nuclear_magneton_ratio     =2.792847337;
PhCoErr.proton_magnetic_moment_to_nuclear_magneton_ratio_err =0.000000029;

PhConst.proton_g_factor                       =5.585694675;
PhCoErr.proton_g_factor_err                   =0.000000057;

PhConst.proton_neutron_magnetic_moment_ratio      =-1.45989805;
PhCoErr.proton_neutron_magnetic_moment_ratio_err  =-0.00000034;

PhConst.shielded_proton_magnetic_moment       =1.410570399e-26*J/T;
PhCoErr.shielded_proton_magnetic_moment_err   =0.000000059e-26*J/T;
-- (H2O, sphere, 25 Cel)

PhConst.shielded_proton_magnetic_moment_to_Bohr_magneton_ratio     =1.520993132e-3;
PhCoErr.shielded_proton_magnetic_moment_to_Bohr_magneton_ratio_err =0.000000016e-3;

PhConst.shielded_proton_magnetic_moment_to_nuclear_magneton_ratio     =2.792775597;
PhCoErr.shielded_proton_magnetic_moment_to_nuclear_magneton_ratio_err =0.000000031;

PhConst.proton_magnetic_shielding_correction      =25.687e-6;
PhCoErr.proton_magnetic_shielding_correction_err  = 0.015e-6;
-- (H2O, sphere, 25 Cel)

PhConst.proton_gyromagnetic_ratio              =2.67522212e8/s/T;
PhCoErr.proton_gyromagnetic_ratio_err          =0.00000011e8/s/T;

PhConst.proton_gyromagnetic_ratio_over_2pi     =42.5774825*MHz/T;
PhCoErr.proton_gyromagnetic_ratio_over_2pi_err = 0.0000018*MHz/T;

PhConst.shielded_proton_gyromagnetic_ratio     =2.67515341e8/s/T;
PhCoErr.shielded_proton_gyromagnetic_ratio_err =0.00000011e8/s/T;
-- (H2O, sphere, 25 Cel)

PhConst.shielded_proton_gyromagnetic_ratio_over_2pi     =42.5763888*MHz/T;
PhCoErr.shielded_proton_gyromagnetic_ratio_over_2pi_err = 0.0000018*MHz/T;

-- Neutron, n ----------------------------------------------------------

PhConst.neutron_mass                          =1.67492716e-27*kg;
PhCoErr.neutron_mass_err                      =0.00000013e-27*kg;

PhConst.neutron_relative_atomic_mass          =1.00866491578;
PhCoErr.neutron_relative_atomic_mass_err      =0.00000000055;

-- (neutron relative atomic mass times u:
-- PhConst.neutron_mass                          =1.00866491578*u;
-- PhCoErr.neutron_mass_err                      =0.00000000055*u;

PhConst.neutron_mass_energy_equivalent        =1.50534946e-10*J;
PhCoErr.neutron_mass_energy_equivalent_err    =0.00000012e-10*J;

-- in MeV (cf. also Remark4)  
-- PhConst.neutron_mass_energy_equivalent        =939.565330*MeV;
-- PhCoErr.neutron_mass_energy_equivalent_err    =  0.000038*MeV;

PhConst.neutron_electron_mass_ratio           =1838.6836550;
PhCoErr.neutron_electron_mass_ratio_err       =   0.0000040;

PhConst.neutron_muon_mass_ratio               =8.89248478;
PhCoErr.neutron_muon_mass_ratio_err           =0.00000027;

PhConst.neutron_tau_mass_ratio                =0.528722;
PhCoErr.neutron_tau_mass_ratio_err            =0.000086;

PhConst.neutron_proton_mass_ratio             =1.00137841887;
PhCoErr.neutron_proton_mass_ratio_err         =0.00000000058;

PhConst.neutron_molar_mass                    =1.00866491578e-3*kg/mol;
PhCoErr.neutron_molar_mass_err                =0.00000000055e-3*kg/mol;

PhConst.neutron_Compton_wavelength            =1.319590898e-15*m;
PhCoErr.neutron_Compton_wavelength_err        =0.000000010e-15*m;

PhConst.neutron_Compton_wavelength_over_2pi       =0.2100194142e-15*m;
PhCoErr.neutron_Compton_wavelength_over_2pi_err   =0.0000000016e-15*m;

PhConst.neutron_magnetic_moment               =-0.96623640e-26*J/T;
PhCoErr.neutron_magnetic_moment_err           =-0.00000023e-26*J/T;

PhConst.neutron_magnetic_moment_to_Bohr_magneton_ratio       =-1.04187563e-3;
PhCoErr.neutron_magnetic_moment_to_Bohr_magneton_ratio_err   =-0.00000025e-3;

PhConst.neutron_magnetic_moment_to_nuclear_magneton_ratio    =-1.91304272;
PhCoErr.neutron_magnetic_moment_to_nuclear_magneton_ratio_err =-0.00000045;

PhConst.neutron_g_factor                           =-3.82608545;
PhCoErr.neutron_g_factor_err                       =-0.00000090;

PhConst.neutron_electron_magnetic_moment_ratio     =1.04066882e-3;
PhCoErr.neutron_electron_magnetic_moment_ratio_err =0.00000025e-3;

PhConst.neutron_proton_magnetic_moment_ratio       =-0.68497934;
PhCoErr.neutron_proton_magnetic_moment_ratio_err   =-0.00000016;

PhConst.neutron_to_shielded_proton_magnetic_moment_ratio     =-0.68499694;
PhCoErr.neutron_to_shielded_proton_magnetic_moment_ratio_err =-0.00000016;
-- (H2O, sphere, 25 Cel)

PhConst.neutron_gyromagnetic_ratio                 =1.83247188e8/s/T;
PhCoErr.neutron_gyromagnetic_ratio_err             =0.00000044e8/s/T;

PhConst.neutron_gyromagnetic_ratio_over_2pi        =29.1646958*MHz/T;
PhCoErr.neutron_gyromagnetic_ratio_over_2pi_err    = 0.0000070*MHz/T;

---- Deuteron, d -------------------------------------------------------

PhConst.deuteron_mass                         =3.34358309e-27*kg;
PhCoErr.deuteron_mass_err                     =0.00000026e-27*kg;

PhConst.deuteron_relative_atomic_mass         =2.01355321271; 
PhCoErr.deuteron_relative_atomic_mass_err     =0.00000000035;

-- deuteron relative atomic mass times u:
-- PhConst.deuteron_mass                         =2.01355321271*u;
-- PhCoErr.deuteron_mass_err                     =constant(0.00000000035*u);

PhConst.deuteron_mass_energy_equivalent       =3.00506262e-10*J;
PhCoErr.deuteron_mass_energy_equivalent_err   =0.00000024e-10*J;

-- in MeV (cf. also Remark4)
-- PhConst.deuteron_mass_energy_equivalent       =1875.612762*MeV;
-- PhCoErr.deuteron_mass_energy_equivalent_err   =   0.000075*MeV;

PhConst.deuteron_electron_mass_ratio          =3670.4829550;
PhCoErr.deuteron_electron_mass_ratio_err      =   0.0000078;

PhConst.deuteron_proton_mass_ratio            =1.99900750083;
PhCoErr.deuteron_proton_mass_ratio_err        =0.00000000041;

PhConst.deuteron_molar_mass                   =2.01355321271e-3*kg/mol;
PhCoErr.deuteron_molar_mass_err               =0.00000000035e-3*kg/mol;

PhConst.deuteron_magnetic_moment              =0.433073457e-26*J/T;
PhCoErr.deuteron_magnetic_moment_err          =0.000000018e-26*J/T;



PhConst.deuteron_magnetic_moment_to_Bohr_magneton_ratio      =0.4669754556e-3;
PhCoErr.deuteron_magnetic_moment_to_Bohr_magneton_ratio_err  =0.0000000050e-3;

PhConst.deuteron_magnetic_moment_to_nuclear_magneton_ratio       =0.8574382284;
PhCoErr.deuteron_magnetic_moment_to_nuclear_magneton_ratio_err   =0.0000000094;

PhConst.deuteron_electron_magnetic_moment_ratio              =-4.664345537e-4;
PhCoErr.deuteron_electron_magnetic_moment_ratio_err          =-0.000000050e-4;

PhConst.deuteron_proton_magnetic_moment_ratio                =0.3070122083;
PhCoErr.deuteron_proton_magnetic_moment_ratio_err            =0.0000000045;

PhConst.deuteron_neutron_magnetic_moment_ratio               =-0.44820652;
PhCoErr.deuteron_neutron_magnetic_moment_ratio_err           =-0.00000011;


-- Helion, h  -----------------------------------------------------------

PhConst.helion_mass                              =5.00641174e-27*kg;   
PhCoErr.helion_mass_err                          =0.00000039e-27*kg;
-- cf. remark 1.e


PhConst.helion_relative_atomic_mass              =3.01493223469;   
PhCoErr.helion_relative_atomic_mass_err          =0.00000000086;   

-- helion relative atomic mass times u:
-- PhConst.helion_mass                              =3.01493223469*u;
-- PhCoErr.helion_mass_err                          =0.00000000086*u;

PhConst.helion_mass_energy_equivalent            =4.49953848e-10*J;
PhCoErr.helion_mass_energy_equivalent_err        =0.00000035e-10*J;

--cf. also Remark4
-- PhConst.helion_mass_energy_equivalent            =2808.39132*MeV;
-- PhCoErr.helion_mass_energy_equivalent_err        =   0.00011*MeV;

PhConst.helion_electron_mass_ratio               =5495.885238;
PhCoErr.helion_electron_mass_ratio_err           =   0.000012;

PhConst.helion_proton_mass_ratio                 =2.99315265850;
PhCoErr.helion_proton_mass_ratio_err             =0.00000000093;

PhConst.helion_molar_mass                        =3.01493223469e-3*kg/mol;
PhCoErr.helion_molar_mass_err                    =0.00000000086e-3*kg/mol;

PhConst.shielded_helion_magnetic_moment          =-1.074552967e-26*J/T;
PhCoErr.shielded_helion_magnetic_moment_err      =-0.000000045e-26*J/T;
-- (gas, sphere, 25 Cel)

PhConst.shielded_helion_magnetic_moment_to_Bohr_magneton_ratio        =-1.158671474e-3;
PhCoErr.shielded_helion_magnetic_moment_to_Bohr_magneton_ratio_err    =-0.000000014e-3;

PhConst.shielded_helion_magnetic_moment_to_nuclear_magneton_ratio     =-2.127497718;
PhCoErr.shielded_helion_magnetic_moment_to_nuclear_magneton_ratio_err =-0.000000025;

PhConst.shielded_helion_to_proton_magnetic_moment_ratio               =-0.761766563;
PhCoErr.shielded_helion_to_proton_magnetic_moment_ratio_err           =-0.000000012;
-- (gas, sphere, 25 Cel)

PhConst.shielded_helion_to_shielded_proton_magnetic_moment_ratio      =-0.7617861313;
PhCoErr.shielded_helion_to_shielded_proton_magnetic_moment_ratio_err  =-0.0000000033;
-- (gas/H2O, spheres, 25 Cel)

PhConst.shielded_helion_gyromagnetic_ratio                 =2.037894764e8/s/T;
PhCoErr.shielded_helion_gyromagnetic_ratio_err             =0.000000085e8/s/T;
-- (gas, sphere, 25 Cel)

PhConst.shielded_helion_gyromagnetic_ratio_over_2pi        =32.4341025*MHz/T;
PhCoErr.shielded_helion_gyromagnetic_ratio_over_2pi_err    = 0.0000014*MHz/T;


-- Alpha particle --------------------------------------------------------

PhConst.alpha_particle_mass                      =6.64465598e-27*kg;
PhCoErr.alpha_particle_mass_err                  =0.00000052e-27*kg;


PhConst.alpha_particle_relative_atomic_mass      =4.0015061747;
PhCoErr.alpha_particle_relative_atomic_mass_err  =0.0000000010;

-- alpha particle relative atomic mass times u:
-- PhConst.alpha_particle_mass                      =4.0015061747*u;
-- PhCoErr.alpha_particle_mass_err                  =0.0000000010*u;

PhConst.alpha_particle_mass_energy_equivalent         =5.97191897e-10*J;
PhCoErr.alpha_particle_mass_energy_equivalent_err     =0.00000047e-10*J;

-- in MeV  (cf. also Remark 4)
-- PhConst.alpha_particle_mass_energy_equivalent         =3727.37904*MeV;
-- PhCoErr.alpha_particle_mass_energy_equivalent_err     =   0.00015*MeV;

PhConst.alpha_particle_to__lectron_mass_ratio         =7294.299508;
PhCoErr.alpha_particle_to__lectron_mass_ratio_err     =   0.000016;

PhConst.alpha_particle_to_proton_mass_ratio           =3.9725996846;
PhCoErr.alpha_particle_to_proton_mass_ratio_err       =0.0000000011;

PhConst.alpha_particle_molar_mass                =4.0015061747e-3*kg/mol;
PhCoErr.alpha_particle_molar_mass_err            =0.0000000010e-3*kg/mol;

-------------------------------------------------------------------------------
-- PHYPhCo-CHEMICAL
-------------------------------------------------------------------------------

PhConst.Avogadro_constant                     =6.02214199e23/mol;
PhCoErr.Avogadro_constant_err                 =0.00000047e23/mol;

-- already defined above
-- the atomic mass constant u:
-- PhConst.atomic_mass_constant                  =1.66053873e-27*kg; 
-- PhCoErr.atomic_mass_constant_err              =0.00000013e-27*kg;          

PhConst.atomic_mass_energy_equivalent         =1.49241778e-10*J;
PhCoErr.atomic_mass_energy_equivalent_err     =0.00000012e-10*J;

-- in MeV  (cf. also Remark 4) 
-- PhConst.atomic_mass_energy_equivalent         =931.494013*MeV;
-- PhCoErr.atomic_mass_energy_equivalent_err     =  0.000037*MeV;

PhConst.Faraday_constant                      =96485.3415*C/mol;     
PhCoErr.Faraday_constant_err                  =    0.0039*C/mol;
-- cf. Remark 1.g

PhConst.molar_Planck_constant                 =3.990312689e-10*J*s/mol;
PhCoErr.molar_Planck_constant_err             =0.000000030e-10*J*s/mol;

PhConst.molar_Planck_constant_times_c         =0.11962656492*J*m/mol;
PhCoErr.molar_Planck_constant_times_c_err     =0.00000000091*J*m/mol;

PhConst.molar_gas_constant                    =8.314472*J/mol/K;
PhCoErr.molar_gas_constant_err                =0.000015*J/mol/K;

PhConst.Boltzmann_constant                    =1.3806503e-23*J/K;
PhCoErr.Boltzmann_constant_err                =0.0000024e-23*J/K;

-- in eV per K  (cf. also Remark 4) 
-- PhConst.Boltzmann_constant                    =8.617342e-5*eV/K; 
-- PhCoErr.Boltzmann_constant_err                =0.000015e-5*eV/K;  

PhConst.Boltzmann_constant_over_h             =2.0836644e10*Hz/K;
PhCoErr.Boltzmann_constant_over_h_err         =0.0000036e10*Hz/K;

PhConst.Boltzmann_constant_over_hc            =69.50356/m/K;
PhCoErr.Boltzmann_constant_over_hc_err        = 0.00012/m/K;

xxx=1
PhConst.molar_volume_of_ideal_gas=xxx
PhCoErr.molar_volume_of_ideal_gas_err=xxx


-- for temperature=273.15 K  and pressure=101.325 kPa =1 atm:
PhConst.molar_volume_of_ideal_gas_for_1atm    =22.413996e-3*m^3/mol;
PhCoErr.molar_volume_of_ideal_gas_for_1atm_err =0.000039e-3*m^3/mol;

PhConst.Loschmidt_constant                    =2.6867775e25/m^3;
PhCoErr.Loschmidt_constant_err                =0.0000047e25/m^3;


-- for temperature=273.15 K; and pressure= 100 kPa:
PhConst.molar_volume_of_ideal_gas_for_100kPa      =22.710981e-3*m^3/mol;
PhCoErr.molar_volume_of_ideal_gas_for_100kPa_err  = 0.000040e-3*m^3/mol;


-- absolute entropy constant 
-- for temperature= 1 K, pressure= 1atm =101.325 kPa
-- cf. Remark 1.h
PhConst.Sackur_Tetrode_constant_for_1atm       =-1.1648678;
PhCoErr.Sackur_Tetrode_constant_for_1atm_err   =-0.0000044;

-- absolute entropy constant 
-- for temperature= 1 K, pressure= 100 kPa
-- cf. Remark 1.h
PhConst.Sackur_Tetrode_constant_for_100kPa     =-1.1517048;
PhCoErr.Sackur_Tetrode_constant_for_100kPa_err =-0.0000044;


PhConst.Stefan_Boltzmann_constant             =5.670400e-8*W/m^2/K^4;
PhCoErr.Stefan_Boltzmann_constant_err         =0.000040e-8*W/m^2/K^4;

PhConst.first_radiation_constant              =3.74177107e-16*W*m^2;
PhCoErr.first_radiation_constant_err          =0.00000029e-16*W*m^2;

PhConst.first_radiation_constant_for_spectral_radiance     =1.191042722e-16*W*m^2/sr;
PhCoErr.first_radiation_constant_for_spectral_radiance_err =0.000000093e-16*W*m^2/sr;

PhConst.second_radiation_constant             =1.4387752e-2*m*K;
PhCoErr.second_radiation_constant_err         =0.0000025e-2*m*K;

-- Wien displacement law constant   b =lambda_max*T = h*c/k/4.965114231...
PhConst.Wien_displacement_law_constant        =2.8977686e-3*m*K;
PhCoErr.Wien_displacement_law_constant_err    =0.0000051e-3*m*K;

-------------------------------------------------------------------------------
-- Remark 1:
-- a -- See the "Adopted values" table for the conventional value
--      adopted internationally for realizing representations of the volt
--      using the Josephson effect.

-- b -- See the "Adopted values" table for the conventional value
--      adopted internationally for realizing representations of the ohm
--      using the quantum Hall effect.

-- c -- Value recommended by the Particle Data Group,
--      Caso et al., Eur. Phys. J. C 3(1-4), 1-794 (1998).

-- d -- Based on the ratio of the masses of the W and Z bosons
--      m_W / m_Z  recommended by the Particle Data Group (Caso et al., 1998).
--      The value for sin^2(Theta_W) they recommend,
--      which is based on a particular variant of the modified minimal subtraction
--      (MS) scheme, is sin^2(Theta^hat_W(M_Z)) = 0.231 24(24)

-- e -- The helion, symbol h, is the nucleus of the 3 He atom.

-- f -- This and all other values involving m_tau are based on the value
--      of m_tau*c^2 in MeV recommended by the Particle Data Group,
--      Caso et al., Eur. Phys. J. C 3(1-4), 1-794 (1998),
--      but with a standard uncertainty of 0.29 MeV rather than the quoted
--      uncertainty of -0.26 MeV, +0.29 MeV.

-- g -- The numerical value of F to be used in coulometric chemical measurements
--      is 96485.3432(76) [7.9e-8] when the relevant current is measured
--      in terms of representations of the volt and ohm based
--      on the Josephson and quantum Hall effects and the
--      internationally adopted conventional values
--      of the Josephson and von Klitzing constants K_(J-90) and R_(K-90)
--      given in the "Adopted values" table.

-- h -- The entropy of an ideal monoatomic gas of relative atomic mass Ar
--      is given by S = S_0 +(3/2)*R*ln(Ar) - R*ln(p/p_0) + (5/2)*R*ln(T/K)

-------------------------------------------------------------------------------
--
-- Source: Peter J. Mohr and Barry N. Taylor,
--         CODATA Recommended Values of the Fundamental Physical Constants. 1998,
--         Journal of Physical and Chemical Reference Data, Vol. 28, No. 6, 1999
--         and Reviews of Modern Physics, Vol. 72, No. 2, 2000.
--
-- From: physics.nist.gov/constants
-- Fundamental Physical Constants
-------------------------------------------------------------------------------

end--do

------------------------------------------------------------------------
-- units accepted for use with the SI
-- wich are depending on physical constants 
------------------------------------------------------------------------


--SI.electron_volt    =constant(PhConst.elementary_charge*SI.volt);
--SIUnits.eV          =constant(SI.electron_volt);

--SI.atomic_mass_unit =constant(PhConst.atomic_mass_constant);
--SIUnits.u           =constant(SI.atomic_mass_unit);
--SIUnits.amu         =constant(SI.atomic_mass_unit);

-------------------------------------------------------------------------------

------------------------------------------------------------------------
-- Remark2: 
--   The values were taken from [2]: 
--   CODATA Internationally recommended values of the 
--   Fundamental physical constants (1998)
--
--   Old values (of 1986) are available from [2]   
--   and from [1] (accordingly to the CODATA-Bulletin Nr. 63, 1986)
--   
-- Remark3:
--   New and old values should not be mixed together!
--
-- Remark4:
--   All the defined constants are measured in units of the international 
--   system (SI). 
--   If it is necessary to know the value in another unit of measurement
--   then the constant has to be devided by that unit. 
--   In this case, of course, that unit  must be expressed  in units of SI.
--   
--   Example:
--   If one wants to print out the Plank constant in eV*s then this can be 
--   done by
--     eV=PhConst.elementary_charge*SIUnits.V;
--     print("Plank constant = ",PhConst.Plank_constant/(eV*SIUnits.s)," eV s");   
--   
-- Remark5:
--   For each physical constant we have defined a constant containing the 
--   standard uncertainty. 
--   To get relative uncertainties, please devide the uncertainty by the value
--   of the corresponding physical constant.  
--   We gave the uncertainty the same sign as the sign of the corresponding 
--   physical constant to obtain positive relative uncertainties after division. 
--   But, of course, the uncertainties are to consider in both directions,
--   plus and minus.
--
--   Example:
--   electron_mass_relative_err = PhCoErr.electron_mass_err/PhConst.electron_mass;  
--     
-- Remark6:
--   The defined constants may be globalized by calling: 
--     globalize(PhConst)   
--   The defined uncertainties may be globalized by calling:
--     globalize(PhCoErr)
--
--
--     function globalize(tbl)
--       local V = next(tbl,nil)
--       while(V) 
--       do 
--         rawsetglobal(V,rawgettable(tbl,V))
--         V=next(tbl,V) 
--       end
--     end
-- 
------------------------------------------------------------------------------
-- References:
-- [1] Fischer, Vogelsang: SI, Groessen und Einheiten in Physik und Technik
--     Verlag Technik Berlin und Muenchen, 6. Auflage, 1993
-- [2] National Institute of Standards and Technology (NIST):
--     Fundamental Physical Constants
--     http://physics.nist.gov/cuu/Constants/index.html
------------------------------------------------------------------------------
-- Notes:
-- * SI    = Le Syste`me International d'Unite's
-- CODATA  = Committee on Data for Science and Technology
------------------------------------------------------------------------------                                



------------------------------------------------------------------------------ 
-- Units of Measurement  - described by units of SI* 
-- most of them are accepted for use with the SI
------------------------------------------------------------------------------

--local const_pi=PI
------------------------------------------------------------------------

  PhUnits ={}  -- all the defined units are collected in this table  

------------------------------------------------------------------------

-- ======================================
-- units depending on physical constants: 
-- ======================================

PhUnits.electron_volt    =PhConst.elementary_charge*SI.volt
PhUnits.eV               =PhUnits.electron_volt

PhUnits.atomic_mass_unit = PhConst.atomic_mass_constant
PhUnits.u                = PhUnits.atomic_mass_unit
--PhUnits.amu              = PhUnits.atomic_mass_unit     


-- ===============      
-- time intervals:
-- ===============

PhUnits.minute       =60*SI.second;      -- time interval            
--PhUnits.min          =PhUnits.minute); -- (ambig. symbol)
      
PhUnits.hour         =3600*SI.second;     -- time interval                      
--PhUnits.h            =PhUnits.hour;        
PhUnits.hr           =PhUnits.hour;  -- (symbol was proposed in [1])

PhUnits.day          =24*3600*SI.second;  -- time interval        
--PhUnits.d            =PhUnits.day;         

-- length of a year:
-- Depending on the usage, there are many different definitions 
-- of the length of a year
--   in Julian calendar:
PhUnits.year         =365.25*24*3600*SI.second; 
PhUnits.ann          =PhUnits.year;        
--   in Gregorian calendar:
-- PhUnits.year         =365.2425*24*3600*SI.second; 
-- PhUnits.ann          =PhUnits.year;        


-- =======
-- angles:
-- =======

PhUnits.degree       =(const_pi/180)*SI.radian; 
PhUnits.deg          =PhUnits.degree;   
       
PhUnits.arcminute    =(const_pi/180/60)*SI.radian; 
PhUnits.mnt          =PhUnits.arcminute;           

PhUnits.arcsecond    =(const_pi/180/3600)*SI.radian; 
PhUnits.sec          =PhUnits.arcsecond;           

-- ==================  
-- logarithmic units:
-- ==================

-- natural logarithm of a ratio 
--PhUnits.neper        =1; 
--PhUnits.Np           =PhUnits.neper;

-- decimal logarithm of a ratio 
--PhUnits.bel          =0.5*ln(10)*PhUnits.neper; 
--PhUnits.dB           =0.1*PhUnits.bel;


-- logarithmic units should better be defined using functions
-- to convert logarithmic units into ratios and vice versa

--PhUnits.neper_to_ratio    = function(x) exp(2*x); end;
--PhUnits.ratio_to_neper    = function(x) 0.5*ln(2); end;

--PhUnits.bel_to_ratio      = function(x) exp(ln(10)*x); end;
--PhUnits.ratio_to_bel      = function(x) ln(x)/ln(10); end;

-- ============
-- area:
-- ============

PhUnits.hectar       =10000*SI.meter^2 
PhUnits.ha           =PhUnits.hectar

-- ============
-- volume:
-- ============
  
PhUnits.liter        =1e-3*SI.meter^3; 
PhUnits.L            =PhUnits.liter;                    
--PhUnits.l            =PhUnits.liter; -- -- "l" looks like "1" (one) 

-- ============
-- mass:
-- ============
  
--PhUnits.ton          =1e3*SI.kilogram; 
--PhUnits.t            =1e3*SI.kilogram;                             
PhUnits.tne          =1e3*SI.kilogram; -- (symbol was proposed in [1])

-- ============
-- other units:
-- ============
						      
-- pressure         
PhUnits.bar          =100e3*SI.pascal;    

-- dyn. viscosity
PhUnits.poise        =0.1*SI.pascal*SI.second; 
PhUnits.P            =PhUnits.poise;
						      
------------------------------------------------------------------------

                             
------------------------------------------------------------------------------
-- References:
-- [1] Fischer, Vogelsang: SI, Groessen und Einheiten in Physik und Technik
--     Verlag Technik Berlin und Muenchen, 6. Auflage, 1993
-- [2] National Institute of Standards and Technology (NIST):
--     International System of Units (SI)
--     http://physics.nist.gov/cuu/Units/index.html 
-- [3] Russ Rowlett (University of North Carolina at Chapel Hill)
--     Units of Measurements
--     http://www.unc.edu/~rowlett/units/index.html
------------------------------------------------------------------------------
-- Notes:
-- * SI = Le Syste`me International d'Unite's
-- 
------------------------------------------------------------------------------


------------------------------------------------------------------------------ 
-- The International System of Units (SI)*  -- Prefix notations --------------
------------------------------------------------------------------------------ 

------------------------------------------------------------------------------
-- Remark1: 
--   Here we introduce some constants for powers of 10 and powers of 2.
--   These notations are only introduced to simplify the definition of units,
--   e.g.  cm     = constant(Centi*meter); 
--         uA     = constant(Micro*ampere);
--         MOhm   = constant(Mega*volt/ampere);
--         Mibyte = constant(Mebi*bit);         -- often written as Mbyte
--
--   In an script files the notation  
--          x= 12*Milli*meter; y = 123*Milli*meter;
--   should not be used. 
--   Please, define  
--          mm= constant(Milli*meter); 
--   before and write 
--          x = 12*mm; y = 123*mm;
--
-- Remark2:        
--   Prefix notations should NOT be used otherwise as units, numbers  
--   or factors, i.e.  notations like  
--          p = 20*Centi;                 -- instead of p = 20*percent;  
--          x = (2*Kilo+3*Milli)*meter;   -- instead of x = 2000.003*m;          
--   are NOT permitted.
--   Multiple prefixes like in 
--          x = Hecto*Milli*meter; -- instead of  x = 0.1*m;
--          w = 3*Micro*kilogram;  -- instead of  w = 3*mg; 
--   are NOT allowed.
--    
-- Remark3: 
--   All prefix symbols should be chosen accordingly to ISO or DIN.
--   They are listed below as comment.
--   These symbols (like m for Milli) should NOT be defined separately 
--   as constants (because of ambiguities and Remark2).
--
-- Remark4: 
--   To avoid ambiguity  
--   we have chosen prefix names beginning with a capital letter.  
------------------------------------------------------------------------------

SIPrefix={}
SIPrefixSymbol={}

--SI prefix notations                     
------------------------- Symbols:
SIPrefix.Yotta =1e24; SIPrefixSymbol.Yotta="Y"; --... 
SIPrefix.Zetta =1e21; SIPrefixSymbol.Zetta="Z"; --... 
SIPrefix.Exa   =1e18; SIPrefixSymbol.Exa="E"; --...  or  EX...  
SIPrefix.Peta  =1e15; SIPrefixSymbol.Peta="P"; --...  or  PE... to distinguish it from p
SIPrefix.Tera  =1e12; SIPrefixSymbol.Tera="T"; --...  
SIPrefix.Giga  =1e9;  SIPrefixSymbol.Giga="G"; --...  
SIPrefix.Mega  =1e6;  SIPrefixSymbol.Mega="M"; --...  or  MA... to distinguish it from m
SIPrefix.Kilo  =1e3;  SIPrefixSymbol.Kilo="k"; --...  
SIPrefix.Hekto =1e2;  SIPrefixSymbol.Hekto="h"; --...  
SIPrefix.Deka  =1e1;  SIPrefixSymbol.Deka="da"; --..  
SIPrefix.Deci  =1e-1; SIPrefixSymbol.Deci="d"; --... 
SIPrefix.Centi =1e-2; SIPrefixSymbol.Centi="c"; --...
SIPrefix.Milli =1e-3; SIPrefixSymbol.Milli="m"; --...
SIPrefix.Micro =1e-6; SIPrefixSymbol.Micro="u"; --...  instead of greek letter mu (cf. ISO 2955)
SIPrefix.Nano  =1e-9; SIPrefixSymbol.Nano="n"; --... 
SIPrefix.Pico  =1e-12;SIPrefixSymbol.Pico="p"; --...
SIPrefix.Femto =1e-15;SIPrefixSymbol.Femto="f"; --...
SIPrefix.Atto  =1e-18;SIPrefixSymbol.Atto="a"; --...
SIPrefix.Zepto =1e-21;SIPrefixSymbol.Zepto="z"; --... 
SIPrefix.Yocto =1e-24;SIPrefixSymbol.Yocto="y"; --...  


--additional prefix notations for powers of 2  (proposed by the IEC**)
----------------------------------------------------------------- symbol:
Kibi  =(1024);       -- (2^10);                -- Ki...
Mebi  =(1048576);    -- (2^20);                -- Mi...
Gibi  =(1073741824); -- (2^30);                -- Gi...
Tebi  =(2^40);       -- (1099511627776);       -- Ti...
Pebi  =(2^50);       -- (1125899906842624);    -- Pi...
Exbi  =(2^60);       -- (1152921504606846976); -- Ei...
------------------------------------------------------------------------

------------------------------------------------------------------------------
-- References:
-- [1] Fischer, Vogelsang: SI, Groessen und Einheiten in Physik und Technik
--     Verlag Technik Berlin und Muenchen, 6. Auflage, 1993
-- [2] National Institute of Standards and Technology (NIST):
--     International System of Units (SI)
--     http://physics.nist.gov/cuu/Units/index.html 
-- [3] Russ Rowlett (University of North Carolina at Chapel Hill)
--     Units of Measurements
--     http://www.unc.edu/~rowlett/units/index.html
------------------------------------------------------------------------------
-- Notes:
-- *  SI  = Le Syste`me International d' Unites
-- ** IEC = International Electrotechnical Commission
------------------------------------------------------------------------------
--[[
This stuff should be put elsewhere
]]

unittools={

-- build up an exclude list.
cptable=function (newtab,table)
local    entry,value=next(table,nil)
      while entry do
         if entry=="Cel" then
         elseif entry=="deg" then
         elseif entry=="rad" then
         elseif entry=="electron_volt" then
         elseif entry=="atomic_mass_unit" then
         else
	 newtab[entry]=value
         end
	 entry,value=next(table,entry)
      end
   end,

pfxtable=function(newtab,table)
local    entry,value=next(table,nil)
      while entry do
         if entry=="Cel" then
         elseif entry=="electron_volt" then
         elseif entry=="kg" then
         elseif entry=="atomic_mass_unit" then
         else
           local pentry,pvalue=next(SIPrefix,nil)
           while pentry do
    	     newtab[SIPrefixSymbol[pentry]..entry]=pvalue*value
             pentry,pvalue=next(SIPrefix,pentry)
           end
         end
	 entry,value=next(table,entry)
      end
   end,
}


-- TODO
-- Provide different tables with /without prefixed units etc.
units={}
unittools.cptable(units,SIUnits)
unittools.pfxtable(units,SIUnits)
unittools.cptable(units,PhUnits)
unittools.cptable(units,PhConst)


unittools=nil

collectgarbage()








